@@ -13,7 +13,7 @@ use WWW::LogicBoxes::PrivateNameServer;
 
 use DateTime;
 
-our $VERSION = '1.2.0'; # VERSION
+our $VERSION = '1.2.1'; # VERSION
 # ABSTRACT: LogicBoxes Domain Representation
 
 has id => (
@@ -136,8 +136,8 @@ sub construct_from_response {
         customer_id           => $response->{customerid},
         status                => $response->{currentstatus},
         verification_status   => $response->{raaVerificationStatus},
-        is_locked             => !!( grep { $_ eq 'transferlock' } @{ $response->{orderstatus} } ),
-        is_private            => $response->{isprivacyprotected} eq 'true',
+        is_locked             => !!( grep { $_ && $_ eq 'transferlock' } @{ $response->{orderstatus} } ),
+        is_private            => $response->{isprivacyprotected} && $response->{isprivacyprotected} eq 'true',
         created_date          => DateTime->from_epoch( epoch => $response->{creationtime}, time_zone => 'UTC' ),
         expiration_date       => DateTime->from_epoch( epoch => $response->{endtime}, time_zone => 'UTC' ),
         ns                    => [ map { $response->{ $_ } } sort ( grep { $_ =~ m/^ns/ } keys %{ $response } ) ],
